#
# spec file for package gromacs
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2015-2019 Christoph Junghans <junghans@votca.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor serial%{nil}

# Section 32-bit archs officially unsupported
# https://gitlab.com/gromacs/gromacs/-/merge_requests/2453
ExcludeArch:    %{ix86} %{arm}
# /Section

%if "%flavor" == ""
ExclusiveArch:  do_not_build
%endif

%if "%flavor" == "openmpi"
%{bcond_without mpi}
%else
%{bcond_with    mpi}
%endif

%if %{with mpi}
%define libname_gromacs libgromacs_mpi10
%define libname_gmxapi libgmxapi_mpi0
%else
%define libname_gromacs libgromacs10
%define libname_gmxapi libgmxapi0
%endif
%define libname_nblib_gmx libnblib_gmx0

%ifarch x86_64
%bcond_without opencl
%else
%bcond_with    opencl
%endif

%bcond_with    tinyxml2
%bcond_without tests

Name:           gromacs%{?with_mpi:-openmpi}
Version:        2025.1
Release:        1.1
%define uversion %{version}
Summary:        Molecular Dynamics Package
License:        Apache-2.0 AND LGPL-2.1-or-later AND BSD-3-Clause
Group:          Productivity/Scientific/Chemistry
URL:            https://www.gromacs.org
Source0:        ftp://ftp.gromacs.org/pub/gromacs/gromacs-%{uversion}.tar.gz
Source1:        ftp://ftp.gromacs.org/pub/manual/manual-%{uversion}.pdf
Source2:        ftp://ftp.gromacs.org/regressiontests/regressiontests-%{uversion}.tar.gz
BuildRequires:  cmake >= 3.13.0
BuildRequires:  fdupes
BuildRequires:  gcc-c++ >= 9
BuildRequires:  lapack-devel
%if %{with opencl}
BuildRequires:  ocl-icd-devel
BuildRequires:  opencl-headers
%endif
%if %{with mpi}
BuildRequires:  openmpi-devel
BuildRequires:  openmpi-macros-devel
%endif
BuildRequires:  pkg-config
BuildRequires:  cmake(GTest)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(muparser)
BuildRequires:  pkgconfig(zlib)
%if %{with tinyxml2}
BuildRequires:  (pkgconfig(tinyxml2) > 3.0 with pkgconfig(tinyxml2) < 7)
%endif
Requires:       gromacs-data = %{version}
%if %{with mpi}
# MPI communication fails on 32bit architectures
ExcludeArch:    %{ix86} %{arm} ppc
%endif

%description
GROMACS is a package to perform molecular dynamics computer
simulations and subsequent trajectory analysis. It is developed for
biomolecules like proteins, but it can be used in several other field
like polymer chemistry and solid state physics.

%package devel
Summary:        Molecular dynamics package
Group:          Development/Libraries/C and C++
Requires:       %{libname_gmxapi} = %{version}-%{release}
Requires:       %{libname_gromacs} = %{version}-%{release}
Requires:       %{libname_nblib_gmx} = %{version}-%{release}
# cmake files refer to /usr/bin/gmx, too
Requires:       %{name} = %{version}-%{release}

%description devel
GROMACS is a package to perform molecular dynamics computer
simulations.

This package contains development libraries and header for GROMACS

%package -n %{libname_gromacs}
Summary:        Libraries for Gromacs
Group:          System/Libraries

%description -n %{libname_gromacs}
GROMACS is a package to perform molecular dynamics computer
simulations.

This package contains libraries for Gromacs

%package -n %{libname_gmxapi}
Summary:        Libraries for Gromacs
Group:          System/Libraries

%description -n %{libname_gmxapi}
GROMACS is a package to perform molecular dynamics computer
simulations.

This package contains libraries for Gromacs.

%package -n %{libname_nblib_gmx}
Summary:        Libraries for Gromacs
Group:          System/Libraries

%description -n %{libname_nblib_gmx}
GROMACS is a package to perform molecular dynamics computer
simulations.

This package contains libraries for Gromacs.

%package bash-completion
Summary:        Bash completion for Gromacs
Group:          Productivity/Other
Supplements:    (bash-completion and gromacs)
Supplements:    (bash-completion and gromacs-openmpi)
BuildArch:      noarch
Provides:       %{name}-bash = %{version}
Obsoletes:      %{name}-bash < %{version}

%description bash-completion
GROMACS is a package to perform molecular dynamics computer
simulations.

This package contains bash completion support for gromacs.

%package doc
Summary:        Documentation for Gromacs
Group:          Productivity/Scientific/Chemistry
BuildArch:      noarch

%description doc
GROMACS is a package to perform molecular dynamics computer
simulations.

This package contains documentation for gromacs.

%package data
Summary:        Data files for Gromacs
Group:          Productivity/Scientific/Chemistry
# Package split
Provides:       gromacs:%{_datadir}/gromacs/README.tutor
Conflicts:      gromacs < %{version}-%{release}
BuildArch:      noarch

%description data
GROMACS is a package to perform molecular dynamics computer
simulations.

This package contains data files for gromacs.

%prep
%autosetup -n gromacs-%{uversion} -p1
tar -xzf %{S:2}
# Force same behavior on 32 and 64 bit archs
sed -i -e '/set(CMAKE_BUILD_WITH_INSTALL_RPATH/ s@.*@# \0@' CMakeLists.txt

%build
%if %{with mpi}
%setup_openmpi
%endif

%global acce None
%ifarch %x86 x86_64
#increase to SSE4.1, AVX_128_FMA, AVX_256 when possible
%global acce SSE2
%endif
%ifarch aarch64
%global simd ARM_NEON_ASIMD
%endif

# Avoid oversubscription, some tests run with 2 Ranks locally
export MAX_TEST_THREADS=$(( %{?_smp_build_ncpus}%{!?_smp_build_ncpus:2} / 2 ))
%cmake \
  -DGMX_VERSION_STRING_OF_FORK=openSUSE \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DCMAKE_VERBOSE_MAKEFILE=TRUE \
  -DCMAKE_C_FLAGS_RELEASE:STRING="%{optflags} -fno-strict-aliasing" \
  -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags}" \
  -DCMAKE_SKIP_RPATH=OFF \
  -DCMAKE_SKIP_INSTALL_RPATH=ON \
  -DGMX_BUILD_UNITTESTS:BOOL=ON \
  -DGMX_EXTERNAL_TINYXML2:BOOL=%{?with_tinyxml:ON}%{!?with_tinyxml:OFF} \
  -DGMX_EXTERNAL_ZLIB:BOOL=ON \
  -DGMX_USE_MUPARSER=EXTERNAL \
  -DGMX_SIMD=%{acce} \
%if %{with mpi}
  -DGMX_MPI=ON \
%else
  -DGMX_MPI=OFF \
  -DGMX_THREAD_MPI=ON \
%endif
%if %{with opencl}
  -DGMX_GPU=OpenCL \
%endif
  -DGMX_OPENMP=ON \
  -DGMX_INSTALL_LEGACY_API=ON \
  -DREGRESSIONTEST_PATH="%{_builddir}/gromacs-%{uversion}/regressiontests-%{uversion}" \
  -DGMX_TEST_NUMBER_PROCS=${MAX_TEST_THREADS} \
  %{nil}
%cmake_build
%cmake_build tests

%install
%cmake_install

# fix shebang
sed -i '1s@env @@' %{buildroot}/%{_bindir}/*.pl

#no need when installed in /usr
rm -f %{buildroot}%{_bindir}/GMXRC*

%if %{without mpi}
# Move bash completion file to correct location
mkdir -p %{buildroot}%{_datadir}/bash_completion.d
#concatenate all gmx-completion*, starting with gmx-completion.bash (fct defs)
cat %{buildroot}%{_bindir}/gmx-completion{,?*}.bash > %{buildroot}%{_datadir}/bash_completion.d/gromacs

cp %{S:1} %{buildroot}%{_datadir}/gromacs

%else
rm -f %{buildroot}%{_bindir}/*.pl
rm -Rf %{buildroot}%{_datadir}/gromacs/*
# nblib_gmx is the same for MPI and non-MPI builds
rm -f %{buildroot}%{_libdir}/libnblib_gmx*
rm -f %{buildroot}%{_mandir}/man1/*
# TODO: Some parts of the devel files are MPI dependent
rm -Rf %{buildroot}%{_datadir}/cmake
rm -Rf %{buildroot}%{_includedir}/*
rm -f %{buildroot}%{_libdir}/*.so
rm -Rf %{buildroot}%{_libdir}/pkgconfig/*
rm -Rf %{buildroot}%{_datadir}/gromacs/opencl
%endif

rm -f %{buildroot}%{_bindir}/gmx-completion*

%fdupes %{buildroot}%{_datadir}/gromacs

%check
%if %{with tests}
# parallel test are broken, gl#gromacs/gromacs#4975
%ctest
%endif

%post   -n %{libname_gromacs} -p /sbin/ldconfig
%postun -n %{libname_gromacs} -p /sbin/ldconfig
%post   -n %{libname_gmxapi} -p /sbin/ldconfig
%postun -n %{libname_gmxapi} -p /sbin/ldconfig
%post   -n %{libname_nblib_gmx} -p /sbin/ldconfig
%postun -n %{libname_nblib_gmx} -p /sbin/ldconfig

%files
%if %{without mpi}
%{_bindir}/gmx
%{_bindir}/*.pl
%else
%{_bindir}/gmx_mpi
%endif

%files -n %{libname_gromacs}
%{_libdir}/libgromacs*.so.*

%files -n %{libname_gmxapi}
%{_libdir}/libgmxapi*.so.*

%if %{without mpi}
%files -n %{libname_nblib_gmx}
%{_libdir}/libnblib_gmx.so.*

%files data
%dir %{_datadir}/gromacs
%{_datadir}/gromacs/top
%doc %{_mandir}/man1/*

%files doc
%dir %{_datadir}/gromacs
%doc %{_datadir}/gromacs/*.pdf
%doc %{_datadir}/gromacs/README*
%doc %{_datadir}/gromacs/COPYING

%files devel
%{_datadir}/gromacs/template
%{_datadir}/cmake
%{_includedir}/gromacs/
%{_includedir}/gmxapi/
%{_includedir}/nblib/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%if %{with opencl}
%dir %{_datadir}/gromacs/opencl
%{_datadir}/gromacs/opencl/gromacs
%endif

%files bash-completion
%dir %{_datadir}/bash_completion.d
%{_datadir}/bash_completion.d/gromacs
%endif

%changelog
* Tue May  6 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2025.1:
  * Fix failing to build with AdaptiveCpp and HeFFTe due to
    incomplete refactoring.
  * Silence compiler warning when building with ARM SVE.
  * Fix CMake issues when building with Plumed
  * Correctly suggest NEON over SVE for CPU builds on Neoverse-v2
    at run time
- Changes from version 2025.0:
  - Too many to list, see
    <https://manual.gromacs.org/2025.0/release-notes/index.html>.
- Bump so version in shared library to keep up with upstream.
* Fri Feb  2 2024 Christoph Junghans <junghans@votca.org>
- Aarch64: fix tests and enable neon support
- Tests have race condition, run them serially
* Thu Feb  1 2024 Christoph Junghans <junghans@votca.org>
- Update to 2024
  * Highlights:
  - The Colvars library can now be used natively from GROMACS. This
    simplifies the use of advanced enhanced sampling simulations.
  - Reduced artifacts from Lennard-Jones pair interactions on the
    pressure by a configurable increase of the Verlet buffer. Can
    lead to a slight performance loss, especially for coarse-grained
    systems.
  - Corrected several aspects of the deform option. Now simulations with
    box deformation behave correctly under high shear or when a solid or
    membrane fractures. This also means that the deform option is now
    suitable for computing viscosities.
  - New option for hydrogen mass repartitioning in grompp enables easy
    access to performance improvements.
  - Improvements to AWH, such as better control of the histogram growth
    factor as well as enabling automatic scaling of the target distribution
    based on the AWH friction metric.
  - Configurable HeFFTe multi-GPU FFT options lets users fine-tune the
    settings for specific use-cases.
  * See https://manual.gromacs.org/2024.0/release-notes/index.html
* Sun Apr  2 2023 andy great <andythe_great@pm.me>
- Update to 2023
  * Highlights:
  - The SYCL GPU implementation, which is the GPU portability
    layer that supports all major GPU platforms, has received
    major extensions in support for both platforms and features.
    To ensure portability in practice, the GROMACS GPU portability
    layer is actively developed with multiple SYCL implementations
    (hipSYCL, oneAPI DPC++, IntelLLVM) and regularly tested on
    multiple GPU backends.
  - SYCL supports more GPU offload features: bonded forces and
    direct GPU-GPU communication with GPU-aware MPI.
  - SYCL hardware support includes AMD (including RDNA support
    added here) and Intel for production as well as NVIDIA GPUs
    (not for production).
  - SYCL optimizations targeting important HPC platforms.
  - PME decomposition has been optimized and extended to support
    offloading the entire PME calculation to multiple GPUs,
    including the FFT computation; when combined with cuFFTmp or
    heFFTe this enables much improved strong scaling
    (experimental feature).
  - CUDA Graph support has been added to execute GPU-resident
    single-/multi-GPU simulations using thread-MPI entirely on the
    GPU to improve performance (experimental feature).
  - New ensemble temperature mdp options allow setting the
    temperature of the ensemble for simulations without
    temperature coupling or with different reference temperatures.
  - With gmx dssp, GROMACS now has a native implementation of the
    DSSP algorithm, which replaces gmx do_dssp.
  * See https://manual.gromacs.org/2023/release-notes/index.html
- Update to 2022.6
  * Bugfix release, see
    https://manual.gromacs.org/2023/release-notes/2022/2022.6.html
- Update to 2022.5
  * Bugfix release, see
    https://manual.gromacs.org/2023/release-notes/2022/2022.5.html
* Wed Dec 28 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2022.4
  * Bugfix release, see
    https://manual.gromacs.org/current/release-notes/2022/2022.4.html
- Drop ustream relax_test_tolerance.patch
* Sun Dec 25 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Exclude MPI flavor on 32 bit architectures, as MPI communication
  does not work correctly.
* Mon Nov  7 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix aarch64 build on 15.x, add relax_test_tolerance.patch
- Relax memory and disk constraints
* Wed Nov  2 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use system muparser package, drop libmuparser2 subpackage
- Use system zlib
- Remove bogus/broken library package obsoletes and provides
- Build openmpi version in separate _multibuild
* Fri Oct 14 2022 Klaus Kämpf <kkaempf@suse.com>
- Update to 2022.3
  * Bugfix release, see
    https://manual.gromacs.org/current/release-notes/2022/2022.3.html
- Update to 2022.2
  * Bugfix release, see
    https://manual.gromacs.org/current/release-notes/2022/2022.2.html
- Update to 2022.1
  * Highlights:
  - Free-energy kernels are accelerated using SIMD, which make
    free-energy calculations up to three times as fast when using GPUs
  - A new formulation of the soft-cored non-bonded interactions for
    free-energy calculations allows for a finer control of the alchemical
    transformation pathways
  - New transformation pull coordinate allows arbitrary mathematical
    transformations of one of more other pull coordinates
  - New interface for multi-scale Quantum Mechanics / Molecular
    Mechanics (QM/MM) simulations with the CP2K quantum chemistry package,
    supporting periodic boundary conditions.
  - grompp performance improvements
  - Cool quotes music playlist
  - Additional features were ported to modular simulator
  - Added AMD GPU support with SYCL via hipSYCL
  - More GPU offload features supported with SYCL (PME, GPU update).
  - Improved parallelization with GPU-accelerated runs using CUDA and
    extended GPU direct communication to support multi-node simulation
    using CUDA-aware MPI.
  * See https://manual.gromacs.org/current/release-notes/2022/2022.1.html
- split off libmuparser2 into separate package
* Wed May  4 2022 Christoph Junghans <junghans@votca.org>
- devel package requires binaries as well
* Wed Apr 27 2022 Jan Engelhardt <jengelh@inai.de>
- Trim boasting from package descriptions.
- Trim descriptions in less important subpackages for length.
- Resolve rpmlint reports:
  * "libgromacs4.x86_64: E: shlib-policy-name-error SONAME:
    libgmxapi.so.0, expected package suffix: 0"
  * "libgromacs4.x86_64: E: shlib-policy-name-error SONAME:
    libgromacs.so.6, expected package suffix: 6"
* Sun Dec  5 2021 Max Lin <mlin@suse.com>
- Update license to "LGPL-2.1-or-later AND Apache-2.0 AND BSD-3-Clause"
* Wed Nov 10 2021 Christoph Junghans <junghans@votca.org>
- Tag build with "openSUSE" for easier debugging by upstream
* Thu Sep 30 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Use openmpi macros to always build with the default openmpi version.
* Mon Jul 12 2021 Christoph Junghans <junghans@votca.org>
- Enabled legacy api needed for votca-csg
* Mon Jun 28 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2021.2:
  * Fixes where mdrun could behave incorrectly.
  * Removed a potential race condition with GPU update (issue
    4024).
  * Avoided issues with global reduction observed with md-vv
    (issue 4031).
  * Prohibited SETTLE interactions for atoms with perturbed masses
    (issue 3959).
  * Rerun now writes pull output correctly (issue 4043).
  * Fixes for ``gmx`` tools.
  * Fix incorrect behaviour with single residue chains in pdb2gmx
    (issue 4029).
  * Fix grompp check for position restraints with absolute
    reference (issue 3996).
  * Fix error when using VMD plugin (issue 3055).
  * Fix file permissions with ``gmx solvate`` and ``gmx genion``
    (issue 4040).
  * Fixes that affect portability.
  * Support for Intel oneAPI compiler 2021.2.
  * Fixed compiler infinity math and MKL flags.
  * Fix Apple OpenCL build (issue 4008).
  * Fixed compilation issue with GCC 11 (issue 4039).
  * Fix bond type in GROMOS force fields (issue 3995).
  * Allow PME on CPU in runs with domain decomposition and GPU
    update (issue 4035).
- Turn SKIP_RPATH=OFF and SKIP_INSTALL_RPATH=ON instead; skipping
  rpath use entirely causes linking issues with tests, but we
  still want to disable rpaths for the installed libs of course.
- Rename %%{name}-bash to %%{name}-bash-completion in keeping with
  naming convention followed by other packages.
- Add lapack-devel to BuildRequires to use system versions of blas
  and lapack.
- CMake 3.13 or higher is required; adapt BuildRequires
  accordingly.
- Disable testing for i586: doesn't work with gmock.
- Adapt to updated cmake options and drop no longer applicable
  ones.
* Mon Jul 27 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Increase default disk size from 3 to 6GB in _constraints file
* Fri Feb 28 2020 Christoph Junghans <junghans@votca.org>
- - version bump to 2019.6 details here:
  http://manual.gromacs.org/documentation/2019.6/release-notes/2019/2019.6.html
  Hightlights:
  - Actually fix PME forces with FE without perturbed q/LJ
  - Avoid overzealous program abort with orientation restraints
  - Calculate Coulomb and LJ reciprocal terms in rerun
  - Added check for inconsistent input of distance restraint labels in gmx disre.
  - Fix compiler errors with Intel compiler
  - Avoid cryptic GPU detection errors when devices are unavailable or out of memory
* Mon Dec 23 2019 Christoph Junghans <junghans@votca.org>
- version bump to 2019.5 details here:
  http://manual.gromacs.org/documentation/2019.5/release-notes/2019/2019.5.html
  Hightlights:
  - Fix use of uninitialized data on PME only ranks
  - Fix out of range memory access with free-energy calculations
  - Fix error with intermolecular interactions and domain decomposition
  - Fix issues with AWH with pull-geometry ‘direction’ to be periodic
  - Remove assertion failure with AWH when not using the initial stage
  - Fix dihedral angle calculation near 180 degree boundary
  - Remove problematic output of gmx angle tool
  - Check that libhwloc headers and runtime match
  - Fix .gro file formatting with large boxes
  - Fix duplicate PDB CONECT record output
* Fri Nov 15 2019 Christoph Junghans <junghans@votca.org>
- version bump to 2019.4 details here:
  http://manual.gromacs.org/documentation/2019.4/release-notes/2019/2019.4.html
  Hightlights:
  - Fix incorrect pressure when atoms in CMAP cross a box boundary
  - Fix incorrect LJ cut-off on GPU when rvdw < rcoulomb
  - Fix (unlikely) missing bonded forces with CUDA GPUs and domain decomposition
  - Fix incorrect reporting of final kinetic energy and temperature
  - Fix segmentation fault in grompp and mdrun with cosine COM pulling
  - Fix grompp not adding angle constraints between constraints
  - Fix gmx wham with angle and dihedral geometries
  - Fix bug in gmx xpm2ps
  - Fix bug in gmx anaeig
  - Fix issue with demux.pl script
  - Fixed writing of gro files with index groups
  - Made gmx make_ndx keep chain IDs
  - Fixes that affect portability
* Wed May  8 2019 Christoph Junghans <junghans@votca.org>
- version bump to 2019.2 details here:
  http://manual.gromacs.org/documentation/2019.2/release-notes/2019/2019.2.html
  Hightlights:
  - Fix L-BGFS minimizer
  - Disallow pull geometry direction-periodic with AWH
  - Fixed mdrun -nsteps option
  - gmx cluster -clndx indices now correct
  - gmx editconf -f in.pdb -o out.pdb again preserves chain IDs
  - Tools again accept .tpr files as input
  - Fix segmentation fault when preparing simulated annealing inputs
  - Fix error in AVX 512 detection code
  - Added warning with the use of GROMOS force fields
  - Prevented internal build of FFTW with clang and AVX-512 SIMD
  - Updated performance guide for recent Intel processors with AVX512 instruction support
* Tue Feb 26 2019 Klaus Kämpf <kkaempf@suse.com>
- add fdupes
* Mon Feb 25 2019 Christoph Junghans <junghans@votca.org>
- version bump to 2019.1 details here:
  http://manual.gromacs.org/documentation/2019.1/release-notes/2019/2019.1.html
  Hightlights:
  - Fix error with 2D/3D dynamic load balancing
  - Fix incorrect LJ repulsion force switching on GPUs
  - Fix segmentation fault in mdrun with domain decomposition
  - Fix segmentation fault with energy minimization with the group scheme
  - Correct free-energy Delta H output with mass lambda’s
  - Prevent mdrun -rerun from writing incorrect free-energy output
  - Fix possible division by zero in enforced-rotation code
  - Fix trjconv -ndec
  - Fix using index file groups when .tpr file not supplied
  - Fix tune_pme
  - Fixes that affect portability
  - Explicitly require 64-bit platforms for OpenCL
* Tue Nov 13 2018 Christoph Junghans <junghans@votca.org>
- version bump to 2018.4 details here:
  http://manual.gromacs.org/documentation/2018.4/release-notes/2018/2018.4.html
  Highlights:
  - Correct PME forces with free energy without perturbed charges/LJ
  - Add constraint contribution to foreign Hamiltonian differences
  - Add mass contribution to foreign Hamiltonian differences
  - Work around bugs with expanded ensemble runs
  - Checkpoint continuations require suitable .tpr files
  - Fix mindist output file checks
  - Fix gmx helix segmentation faults
  - Fix bug in entropy calculation in gmx anaeig
  - Fixed an issue where the log file could sometimes report an incorrect initial dynamic load balancing state
  - Fix Bromine parameters in amber forcefield files
  - Made normal-mode analysis work for more than one molecule
  - Disallow rerun using same filename as output file
  - Fix issue when building GROMACS without TNG
* Wed Nov  7 2018 Christoph Junghans <junghans@votca.org>
- version bump to 2018.3 details here:
  http://manual.gromacs.org/documentation/2018.3/release-notes/2018/2018.3.html
  Highlights:
  - Multi-domain GPU runs can no longer miss pair interactions
  - Fix Conjugate Gradient assertion failure at end of minimization
  - Multi-domain Conjugate Gradient minimimization no longer segfaults.
  - Fix pairlist buffer with Brownian Dynamics
  - Avoid “atom moved to far” errors
  - grompp now checks that pull groups are not close to half the box size
  - Fixed segmentation fault in mdrun with QM/MM ONIOM scheme
  - Fixed syntax error in make_gromos_rtp.py
  - Fix gmx solvate topology updating
  - Fix bfactor output error caused by fix for Issue 2511
  - Made sure that gmx rms can skip values
  - Fix trjconv when not providing structure file
  - Fix enforced rotation energy output
  - Fix nvcc host compiler check triggering
  - Report up to date hwloc version information
  - Disable single compilation unit with CUDA 9.0
  - Avoid aborting mdrun when GPU sanity check detects errors
  - Improve OpenCL kernel performance on AMD Vega GPUs
* Sat Jul 21 2018 junghans@votca.org
- version bump to 2018.2 details here:
  http://manual.gromacs.org/documentation/2018.2/release-notes/2018/2018.2.html
  Highlights:
  - Prevented OpenCL timing memory leak
  - Fixed MPI error after constraint failure during energy minimization
  - Fixed moving frozen atoms with constraints
  - Fixed COM removal moving frozen atoms
* Wed Apr  4 2018 junghans@votca.org
- version bump to 2018.1 details here:
  http://manual.gromacs.org/documentation/2018.1/release-notes/2018/2018.1.html
  Highlights:
  - Fixed leap-frog integrator with Nose-Hoover T coupling and Parrinello-Rahman P coupling
  - Used SIMD bondeds without perturbed interactions
  - Fixed bonds whose displacement was zero
  - Fixed centre-of-mass motion removal on part of the system
  - Fixed multi-simulations with multiple ranks per simulation
  - Improved inter-simulation signalling implementation
  - Fixed FEP calculations with SHAKE
  - Fixed handling of mdp define statement assigning preprocessor values
  - Prevented log file energy average printing dividing by zero
* Fri Mar 23 2018 guillaume.gardet@opensuse.org
- Add _constraints file to avoid build failure and timeout on tests
  for slow CPU workers
* Fri Jan 19 2018 junghans@votca.org
- version bump to 2018 details here:
  http://manual.gromacs.org/documentation/2018/ReleaseNotes/index.html
  Highlights:
  - A new dual-list dynamic-pruning algorithm for the short-ranged interactions
  - PME long-ranged interactions can now run on a single GPU
  - AWH (Accelerated Weight Histogram) method is now supported
  - A physical validation suite is added, which runs a series of short simulations
  - Conserved quantities are computed and reported for more integration schemes
- disable GPU on ppc64le, build error
- use internal tinyxml2 as tinxml-6 is broken with gromacs, only testing is build it anyhow
* Sat Nov  4 2017 junghans@votca.org
- enable GPU support via OpenCL
* Wed Oct 25 2017 kkaempf@suse.com
- adapt to new openlmi package - source mpivars.h during build
* Fri Sep 15 2017 junghans@votca.org
- version bump to 2016.4 details here:
  http://manual.gromacs.org/documentation/2016.4/ReleaseNotes/index.html
  Highlighs:
  - Disabled PME tuning with the group scheme
  - Fixed value of Ewald shift
  - Fixed orientation restraint reference
  - Fixed bugs with setup for orientation restraints
  - Worked around missing OpenMP implementation in orientation restraints
  - Enable group-scheme SIMD kernels on recent AVX extensions
  - Fix FEP state with rerun
  - Fixed COM pull force with SD
  - Fix PBC bugs in the swap code
  - Fixed flat-bottomed position restraints with multiple ranks
  - Fixed null pointer print in DD
  - Improved the “files not present” error message
  - Fixed LJ-PME + switch grompp error
  - Fixed unused SIMD PME table kernel
  - Fixed bugs in most double-precision Simd4 implementations
  - Avoid inf in SIMD double sqrt()
  - Fix NVML error messages
  - Fixed IMD interface malfunctions
  - Fixed initial temperature reporting
  - Fix exception in SIMD LJ PME solve
* Tue Aug  8 2017 junghans@votca.org
- Fix build on Factory
* Mon May  8 2017 junghans@votca.org
- __builddir is not overwritable on SLE-12, so use subdirs
- disable test on s390x (too slow)
* Tue Mar 14 2017 junghans@votca.org
- version bump to 2016.3 details here:
  http://manual.gromacs.org/documentation/2016.1/ReleaseNotes/index.html
- Highlights:
  - Made distance restraints work with threads and DD
  - Fixed Ewald surface+3DC corrections
  - Fixed opening of wall table files
  - Fixed bug in gmx insert-molecules.
  - Made virial reproducible
  - Updated to support FFTW 3.3.5
  - Permitted automatic load balancing to disable itself when it makes the run slower
  - Improved the accuracy of timing for dynamic load balancing with GPUs
  - Corrected kernel launch bounds for Tesla P100 GPUs
  - Improved logic handling if/when the run is terminated for SETTLE warnings
  - Fixed bug in gmx wham for reading pullx files.
  - Fixed ouput bug in gmx wham
  - Fixed deadlock with thread-MPI
  - Made error reporting in grompp more user friendly
  - Fixed SIMD suggestion for VMX
  - Fixed script xplor2gmx.pl to work with GMXDATA
  - Fixed default nice level in mdrun-only build
  - Fixed math-test false positive
  - Improved documentation
  - OpenCL error string are now written, instead of cryptic error codes
  - Fixed build with GMX_USE_TNG=off
  - Removed variable-precision .gro writing
  - Fixed BG/Q platform files and install guide
  - Reduced the memory required for free-energy simulations
* Sat Nov  5 2016 junghans@votca.org
- version bump to 2016.1 details here:
  http://manual.gromacs.org/documentation/2016/ReleaseNotes/index.html
- Highlights:
  - Made distance restraints work with threads and DD
  - Fixed Ewald surface+3DC corrections
  - Fixed opening of wall table files
  - Fixed bug in gmx insert-molecules.
  - Made virial reproducible
  - Permitted automatic load balancing to disable itself when it makes the run slower
  - Improved the accuracy of timing for dynamic load balancing with GPUs
  - Corrected kernel launch bounds for Tesla P100 GPUs
  - Improved logic handling if/when the run is terminated for SETTLE warnings
  - Fixed bug in gmx wham for reading pullx files.
  - Fixed ouput bug in gmx wham
  - Fixed deadlock with thread-MPI
  - Made error reporting in grompp more user friendly
  - Fixed SIMD suggestion for VMX
  - Fixed script xplor2gmx.pl to work with GMXDATA
  - Fixed default nice level in mdrun-only build
  - Fixed math-test false positive
  - Improved documentation
  - Fixed build with GMX_USE_TNG=off
  - Removed variable-precision .gro writing
  - Reduced the memory required for free-energy simulations
* Wed Aug 24 2016 junghans@votca.org
- version bump to 2016 details here:
  http://manual.gromacs.org/documentation/2016/ReleaseNotes/index.html
- Highlights:
  - As always, we’ve got several useful performance improvements, with or without GPUs. CPU-side SIMD and threading enhancements will make GPU-accelerated simulations faster even if we’d left the GPU code alone! Thanks to these and additional GPU kernel improvements, in GPU-accelerated runs expect around 15%% improvement in throughput. (And not just for plain vanilla MD, either... the pull code now supports OpenMP threading throughout, and multi-simulations have less coupling between simulations.)
  - We have a new C++11 portability layer permitting us to accelerate in SIMD on the CPU lots of minor routines. These will also often improve runs that use accelerators or many nodes through better load balancing. POWER8, ARM64, AVX512 (KNL), and more are fully SIMD accelerated now because they are supported in the new portability layer!
  - We made further SIMD acceleration of bonded interactions which reduces their calculation time by about a factor of 2. This improves load balance at high parallelization by a factor of 2, and shows significantly better scaling.
  - Similarly, SIMD acceleration of SETTLE reduces the time for constraints by a factor of 3 to 5 - which has a strong effect for GPU runs.
  - OpenCL GPU support is now available with all combinations of MPI, thread-MPI and GPU sharing (ie. the same as CUDA). Kernel performance has improved by up to 60%%. AMD GPUs benefit the most, OpenCL on NVIDIA is generally still slow.
  - Tools in the new analysis framework can handle trajectories that are subsets of the simulation system.
  - New pull coordinate geometries angle-axis, dihedral, and normal angle.
  - Checkpoint restarts work only in the cases where the implementation can always do what the user wants.
  - The version numbering has changed to be the year of the release, plus (in future) a patch number. GROMACS 2016 will be the initial release from this branch, then GROMACS 2016.1 will have the set of bugs that have been fixed in GROMACS 2016, etc.
* Wed Oct 14 2015 junghans@votca.org
- version bump to 5.1 details here:
  http://manual.gromacs.org/documentation/5.1/ReleaseNotes/index.html
- html documentation is gone
- devel package now includes cmake macros and config files
* Wed Oct  8 2014 junghans@votca.org
- version bump to 5.0.2
- Details: http://www.gromacs.org/About_Gromacs/Release_Notes/Versions_5.0.x
* Sat Sep  6 2014 junghans@votca.org
- version bump to 5.0.1
- Details: http://www.gromacs.org/About_Gromacs/Release_Notes/Versions_5.0.x
* Mon Feb 10 2014 junghans@votca.org
- added %%check
* Sun Feb  9 2014 junghans@votca.org
- version bumped to 4.6.5
- fix GMX_CPU_ACCELERATION to SSE2 for older i386 machines
- added openmpi package
- split doc, bash-completion into separate packages
* Tue Mar  5 2013 kkaempf@suse.com
- Update to 4.6.1
  Bugfix release
  - increased shared object major version to 8, #1147
  - updates to HTML manual, install guide, PDF manual, shell completions
    copious minor bug fixes
  - various build system upgrades and fixes #1143
  - new and enhanced error messages
  - fixes for AdResS bugs (neighbour list construction, flop accounting,
    multiple tf tables)
  - fixed PME timing counter issues #1125
  - fixed PME load balance reporting
  - fixed forcerec to work with tools like genion and g_disre #1136
  - various GPU performance enhancements
  - fixed sd integrator with OpenMP threading #1138
  - various minor fixes for interacting with CUDA for GPUs
  - fixes for g_tune_pme to cope with new mdrun behaviour and changed
    command-line options (for both g_tune_pme and mdrun)
  - more checks for system support for setting thread affinities
  - removed inter-flag dependency in g_order
  - fixed issues with free-energy pertubation soft-core and cut-offs #1146
  - fixed issues with md-vv + nose-hoover + (nstcalcenergy > nsttcouple)
    [#1129]
  - incorporated new changes from release 4.5.x branch
  - prevented building with icc 11.1 and SSE4.1 because of known problems
    [#1126]
  - adding warning about not building with icc version < 12 #1126
  - fixed bug sorting atoms with GPUs introduced since 4.6 #1153
  - fixed issues with automated download of regression tests #1150
  - fixed bug with DD cut-off check and PME dynamic load balancing #1169
* Mon Feb  4 2013 kkaempf@suse.com
- Update to 4.6
  New features
  - New Verlet non-bonded scheme which, by default, uses exact cut-off's
    and a buffered pair-list.
  - Multi-level hybrid parallelization (MPI + OpenMP + CUDA):
    full OpenMP multithreading with the Verlet scheme;
  - OpenMP mulitthreading for PME-only nodes with the group scheme;
    native GPU acceleration using CUDA (supporte NVIDIA hardware).
  - New x86 SIMD non-bonded kernels for the usual cut-off scheme, called
    group scheme and the new verlet scheme, use x86 SIMD intrinsics (no
    more assembly code):
    SSE2
    SSE4.1
    AVX-128-FMA (for AMD Bulldozer/Piledriver)
    AVX-256 (for Intel Sandy/Ivy Bridge)
  - Automated OpenMP thread count choice to use all available cores.
  - Automated CPU affinity setting: locking processes or threads to cores.
  - Automated PP-PME (task) load-balancing: balancing non-bonded force and
    PME mesh workload when the two are executed on different
    compute-resources (i.e CPU and GPU or different CPUs). This enables
    GPU-CPU and PP-PME process load balancing by shifting work from the
    mesh to the non-bonded calculation.
  - PPPM/P3M with analytical derivative at the same cost and with the same
    features as PME.
  - New, advanced free energy sampling techniques.
  - AdResS adaptive resolution simulation support.
  - Enforced rotation ("rotational pulling")
  - Build configuration now uses CMake, configure+autoconf/make no longer
    supported. (The CMake build system features with a lot of automation
    and cleverness under the hood and we know that the it might not always
    prove to be as rock-solid as the old one. However, far more advanced
    and complex, so bear with us while we iron out issues that come up
    along the way.)
  - g_hbond now utilizes OpenMP.
  Plus plenty of bug fixes.
* Mon Jun  4 2012 toddrme2178@gmail.com
- Clean up spec file
* Wed Sep 21 2011 kkaempf@suse.com
- Clean up spec file
- Update to 4.5.5
  - Improved pdb2gmx -chainsep option and reintroduced the -merge option.
  - Fixed mdrun file appending truncating files to 0 bytes when
    continuation runs stopped before writing new output.
  - Fixed COM pulling with multiple constraints checking the
    convergence of one constraint instead of all.
  - Fixed some dihedrals in sugars in Gromos53a5/6 working on the
    wrong atoms.
  - AmberGS force field is now based on Amber94 instead of Amber96.
  - Moved hydrogens in Charmm27 protein termini to separate charge
    groups and added ACE and CT3 residue types.
  - Many small fixes which avoid termination with fatal errors or
    crashes in mdrun and tools.
  - Many small updates to the manual pages of programs.
* Tue Mar 22 2011 kkaempf@novell.com
- Update to 4.5.4
  - Fixed pdb2gmx picking up force field from local instead of
    library directory
  - Made pdb2gmx vsite generation work again for certain His
    namings.
  - Fixed incorrect virial and pressure averages with certain
    nst... values (instantaneous values correct)
  - Fixed incorrect cosine viscosity output
  - New -multidir alternative for mdrun -multi option
  - Several minor fixes in analysis tools
  - Several updates to the program documentation
* Wed Nov 10 2010 kkaempf@novell.com
- Update to 4.5.3
  - Double precision energy file reading
  - CHARMM and GB issues
  - Support for Altivec (PowerPC) with CMake
  - Running binaries within the CMake build tree is now possible
  - Various other fixes
* Thu Oct  7 2010 kkaempf@novell.com
- Update to 4.5.1
  - fix bnc#642828 (CVE-2010-4001: Insecure use of LD_LIBRARY_PATH)
  See http://www.gromacs.org/About_Gromacs/Release_Notes/Version_4.5
  for a full list of changes
  - 2D decomposition support for PME: improved load balancing with
    up to 40%% overall performance improvement for large systems.
  - Memory usage is improved for very large systems, allowing
    simulations of >100 million atoms.
  - Running on multi-core nodes now automatically uses thread-
    based parallelization.
  - GPU computing support
  - Check-pointing is made more secure:MD5sum are used to verify
    that all files are correctly in-place before a simulation is
    appended. Output file appending at continuation is turned on
    by default
  - Full Cmake support. Autoconf/automake will be deprecated after
    the final 4.5 release!
  - Full support for 7 AMBER force fields
  - Support for CHARMM27, including cmap for dihedrals
  - Efficient Generalized-Born implicit solvent support including
    the Still/HCT/OBC-models to compute the Born radii, a novel way
    of tabulating the generalized Born-interaction formula for
    greater speed, and optimized SSE-routines for both cut-off and
    all-vs-all simulations.
  - Support for nucleic acid simulations
  - Support for Velocity-Verlet integrators for reversible T- and
    P-coupling; MTTK pressure control integrators; Nose-Hoover
    chains
  - Support for Bennett acceptance ratio (BAR) free energy
    calculations
  - Decoupling group setup for free energy
  - File formats: All GROMACS tools can now read any VMD supported
    trajectory format, without converting trajectory first. (VMD
    is required)
  - g_rdf was a little bit enhanced that structure factors can be
    calculated for any system, by supplying the necessary data via
    sfactor.dat. Most of the common atomtypes are already contained,
    but everybody who needs more freedom can enhance the table
  - Library support for "dynamic index groups" based on textual
    selections (experimental feature). See the tool g_select, the
    included template.c, or Doxygen documentation for information on
    how to write analysis tools using the library. Existing tools
    have not (yet) been converted.
  - g_tune_pme: For a given number of processes or threads this tool
    systematically times mdrun with various numbers of PME-only nodes
    and determines which setting is fastest. It also checks whether
    performance can be enhanced by shifting load between the real and
    the reciprocal space part of the Ewald sum.
  - g_membed: a very convenient utility for embedding membrane
    proteins into equilibrated lipid bilayers
* Sat May 22 2010 cristian.rodriguez@opensuse.org
- read "/dev/urandom" instead of /dev/random
* Sat Jun 20 2009 coolo@novell.com
- fix build with automake 1.11
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Tue Oct  7 2008 kkaempf@suse.de
- Fix buffer overflow (gcc static detection) in calcmu.c
* Sun Oct 15 2006 schwab@suse.de
- Use install-exec-hook instead of install-hook.
- Use AM_PROG_AS.
* Wed Jul 19 2006 kkaempf@suse.de
- update to 3.3.1
  see http://www.gromacs.org for a complete list of changes.
* Mon Jun 19 2006 schwab@suse.de
- Set datadir.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 ro@suse.de
- added .so symlink to filelist
* Wed Aug 11 2004 kkaempf@suse.de
- bugfix update to 3.2.1
* Mon Feb 23 2004 kkaempf@suse.de
- rename 'disco' to 'g_disco' to avoid nameclash with package mono
- build with -fno-strict-aliasing
- return value from main()
* Tue Feb 17 2004 kkaempf@suse.de
- remove obsolete libtool from "configure.ac".
- use proper automake syntax in "acinclude.m4".
- add missing FF.dat as advised on gromacs-users mailing list.
* Tue Feb  3 2004 kkaempf@suse.de
- update to 3.2
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Fri Jun 13 2003 kukuk@suse.de
- Add missing directories to filelist and fix permissions
* Wed Nov 20 2002 ro@suse.de
- work around automake problem
* Fri Nov 15 2002 uli@suse.de
- removed lesstif from neededforbuild (not used)
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xshared xdevel> to <x-devel-packages>
* Tue Oct 29 2002 ro@suse.de
- removed own libtool hacks from acinclude.m4
* Mon Jul 29 2002 kkaempf@suse.de
- Initial version 3.1.4
